@@ -20,6 +20,7 @@ from lesscode_flask.setup import setup_blueprint, setup_logging, setup_query_run
     setup_redis, setup_login_manager, setup_resource_register, setup_data_download, setup_scheduler, \
     setup_common_resource, setup_task
 from lesscode_flask.signals import app_runed
+from lesscode_flask.utils.decorator.sql_injection import contains_sql_injection
 from lesscode_flask.utils.helpers import inject_args, generate_uuid, app_config
 from lesscode_flask.utils.json.NotSortJSONProvider import NotSortJSONProvider
 from lesscode_flask.utils.limit import RedisRateLimiter
@@ -68,7 +69,6 @@ class Lesscoder(Flask):
 
     def preprocess_request(self) -> ft.ResponseReturnValue | None:
         v = super(Lesscoder, self).preprocess_request()
-
         if  hasattr(self, 'countLimiter') and self.countLimiter:
             allowed, remaining = self.countLimiter.is_allowed(*get_count_limit_info())
             if not allowed:
@@ -143,7 +143,10 @@ class Lesscoder(Flask):
         # 此处增加参数注入代码
         params_dict = inject_args(req, func, view_args)
         params_dict.update(view_args)
-        print("params_dict", params_dict)
+        SQL_INJECTION_ENABLE = self.config.get("SQL_INJECTION_ENABLE", False)
+        if SQL_INJECTION_ENABLE:
+            if contains_sql_injection(params_dict):
+                ResponseResult.fail("参数包含非法字符，请调整后重试！", status_code="403", http_code="403")
         # 调用处理函数执行请求处理
         result = self.ensure_sync(func)(**params_dict)
         # 获取不包装路径
